==> cybersource-rest-client-python-0.0.29.tar.gz: cybersource-rest-client-python-0.0.29/authenticationsdk/util/GlobalLabelParameters.py <==
import os
class GlobalLabelParameters:
    POST = "POST"
    GET = "GET"
    PUT = "PUT"
    DELETE = "DELETE"
    PATCH = "PATCH"
    GET_LOWER_CASE = "get "
    POST_LOWER_CASE = "post "
    PUT_LOWER_CASE = "put "
    DELETE_LOWER_CASE = "delete "
    PATCH_LOWER_CASE = "patch "
    HTTP_URL_PREFIX = "https://"
    HTTP = "HTTP_Signature"
    MERCHANT_ID = "v-c-merchant-id"
    AUTHORIZATION_BEARER = "Authorization"
    REQUEST_TARGET = "(request-target)"
    PUBLIC_KEY = "x5c"
    JWT = "JWT"
    OAUTH = "OAUTH"
    MUTUAL_AUTH = "MUTUAL_AUTH"
    DATE = "Date"
    HOST = "Host"
    SIGNATURE = "Signature"
    USER_AGENT = "User-Agent"
    USER_AGENT_VALUE = "Mozilla/5.0"
    CONTENT_TYPE = "Content-Type"
    APPLICATION_JSON = "application/json"
    V_C_CORRELATION_ID = "v-c-correlation-id"
    DIGEST = "Digest"
    REQUEST_TYPE = "Request Type"
    URL = "URL"
    DIGEST_PREFIX = "SHA-256="
    P12_PREFIX = ".p12"
    SIGNATURE_HEADER = ", signature=\""
    ALGORITHM = ", algorithm=\"HmacSHA256\""
    HEADERS_PARAM = ", headers=\""
    MASKING_VALUE = "XXXXX"
    JWT_TIME = "iat"
    JWT_ALGORITHM = "digestAlgorithm"
    JWT_DIGEST = "digest"
    CYBS_FILE_NAME = 'config_params'
    KEY_ID = "keyid=\""
    LOG_FILE_NAME_DEFAULT = "cybs"
    OLD_RUN_ENVIRONMENT_CONSTANTS = ["CYBERSOURCE.ENVIRONMENT.SANDBOX", "CYBERSOURCE.ENVIRONMENT.PRODUCTION", "CYBERSOURCE.IN.ENVIRONMENT.SANDBOX", "CYBERSOURCE.IN.ENVIRONMENT.PRODUCTION"]
    HIDE_MERCHANT_CONFIG_PROPS = "merchantid,merchant_secretkey,merchant_keyid,key_alias,key_password"
    PROXY_PREFIX = "https"
    FILE_NOT_FOUND = "File not found. Check path/filename entered. Entered path/filename : "
    SYSTEM_ERROR = "System error encountered while accessing file : "
    AUTH_ERROR = "Check Authentication Type (HTTP_Signature/JWT) in cybs.json."
    KEY_ALIAS_NULL_EMPTY = "KeyAlias Empty/None. Assigining merchantID value"
    INVALID_KEY_ALIAS = "KeyAlias Invalid. Assigining merchantID value"
    REQUEST_JSON_ERROR = "Request Json File missing. File Path :: "
    KEY_FILE_EMPTY = "KeyFileName is empty, Assigining merchantID value"
    REFER_LOG = "Please refer Log for details"
    MERCHANTID_REQ = "MerchantID is mandatory"
    NOT_ENTERED = "The Following Parameter is Missing in Cybs.Json::"
    INCORRECT_KEY_PASSWORD = "The Entered key_password is Incorrect"
    AUTHENTICATION_REQ = "AuthenticationType is Mandatory"
    MERCHANT_KEY_ID_REQ = "MerchantKeyId is Mandatory"
    MERCHANT_SECRET_KEY_REQ = " MerchantSecretKey is Mandatory"
    PORTFOLIO_ID_REQ = " Portfolio ID is Mandatory"
    KEY_PASSWORD_EMPTY = "KeyPassword Empty/None. Assigining merchantID value"
    INVALID_KEY_PASSWORD = "KeyPassword Invalid. Assigining merchantID value"
    KEY_DIRECTORY_EMPTY = "KeysDirectory not provided. Using Default Path:"
    ENABLE_CLIENT_CERT_EMPTY = 'Enable Clientcert is Empty/Null.'
    CLIENT_CERT_DIR_EMPTY = 'Client Cert Directory is Empty/Null'
    SSL_CLIENT_CERT_EMPTY = 'SSL Client Cert is Empty/Null'
    PRIVATE_KEY_EMPTY = 'Private Key is Empty/Null'
    SSL_KEY_PASSWORD_EMPTY = 'SSL Key Password is Empty/Null'
    CLIENT_ID_EMPTY = 'Client Id is Empty/Null'
    CLIENT_SECRET_EMPTY = 'Client Secret is Empty/Null'
    ACCESS_TOKEN_EMPTY = 'AccessToken is Empty/Null'
    REFRESH_TOKEN_EMPTY = 'RefreshToken is Empty/Null'
    REQUEST_JSON_EMPTY = "RequestJsonPath not provided"
    INVALID_REQUEST_TYPE_METHOD = "Entered Request Type should be (GET/POST/PUT/PATCH)"
    RUN_ENVIRONMENT_EMPTY = "RunEnvironment Is Mandatory."
    DEFAULT_LOG_FILE_NAME = "Log File Name Empty/None.Using Default Value"
    DEFAULT_ENABLE_LOG = True
    DEFAULT_MAXIMUM_SIZE = 10487560
    DEFAULT_TIMEOUT = 1000
    DEFAULT_LOG_DIRECTORY =os.path.join(os.getcwd(),"Logs")
    DEFAULT_PROXY_ADDRESS = "userproxy.visa.com"
    DEFAULT_PROXY_PORT = 443
    DEFAULT_KEY_FILE_PATH = os.path.join(os.getcwd(),"resources")
    ENABLE_LOG_DEFAULT_MESSAGE = "Enable log value Empty/None.Using Default Value"
    LOG_MAXIMUM_SIZE_DEFAULT_MESSAGE = "Log Maximum Size Empty/None.Using Default Value"
    LOG_DIRECTORY_DEFAULT_MESSAGE = "Log Directory value Empty/None.Using Default Value"
    LOG_DIRECTORY_INCORRECT_MESSAGE = "Log Directory value Incorrect.Using Default Value"
    INVALID_CYBS_PATH = "The Cybs.Json Path Provided Is Incorrect"
    DEPRECATED_RUN_ENVIRONMENT = "The value provided for this field `RunEnvironment` has been deprecated and will not be used anymore.\n\nPlease refer to the README file [ https://github.com/CyberSource/cybersource-rest-samples-node/blob/master/README.md ] for information about the new values that are accepted."

==> cybersource-rest-client-python-0.0.40.tar.gz: cybersource-rest-client-python-0.0.40/authenticationsdk/util/GlobalLabelParameters.py <==
import os
class GlobalLabelParameters:
    POST = "POST"
    GET = "GET"
    PUT = "PUT"
    DELETE = "DELETE"
    PATCH = "PATCH"
    GET_LOWER_CASE = "get "
    POST_LOWER_CASE = "post "
    PUT_LOWER_CASE = "put "
    DELETE_LOWER_CASE = "delete "
    PATCH_LOWER_CASE = "patch "
    HTTP_URL_PREFIX = "https://"
    HTTP = "HTTP_Signature"
    MERCHANT_ID = "v-c-merchant-id"
    AUTHORIZATION_BEARER = "Authorization"
    REQUEST_TARGET = "(request-target)"
    PUBLIC_KEY = "x5c"
    JWT = "JWT"
    OAUTH = "OAUTH"
    MUTUAL_AUTH = "MUTUAL_AUTH"
    DATE = "Date"
    HOST = "Host"
    SIGNATURE = "Signature"
    USER_AGENT = "User-Agent"
    USER_AGENT_VALUE = "Mozilla/5.0"
    CONTENT_TYPE = "Content-Type"
    APPLICATION_JSON = "application/json"
    V_C_CORRELATION_ID = "v-c-correlation-id"
    DIGEST = "Digest"
    REQUEST_TYPE = "Request Type"
    URL = "URL"
    DIGEST_PREFIX = "SHA-256="
    P12_PREFIX = ".p12"
    SIGNATURE_HEADER = ", signature=\""
    ALGORITHM = ", algorithm=\"HmacSHA256\""
    HEADERS_PARAM = ", headers=\""
    MASKING_VALUE = "XXXXX"
    JWT_TIME = "iat"
    JWT_ALGORITHM = "digestAlgorithm"
    JWT_DIGEST = "digest"
    CYBS_FILE_NAME = 'config_params'
    KEY_ID = "keyid=\""
    LOG_FILE_NAME_DEFAULT = "cybs"
    OLD_RUN_ENVIRONMENT_CONSTANTS = ["CYBERSOURCE.ENVIRONMENT.SANDBOX", "CYBERSOURCE.ENVIRONMENT.PRODUCTION", "CYBERSOURCE.IN.ENVIRONMENT.SANDBOX", "CYBERSOURCE.IN.ENVIRONMENT.PRODUCTION"]
    HIDE_MERCHANT_CONFIG_PROPS = "merchantid,merchant_secretkey,merchant_keyid,key_alias,key_password"
    PROXY_PREFIX = "https"
    FILE_NOT_FOUND = "File not found. Check path/filename entered. Entered path/filename : "
    SYSTEM_ERROR = "System error encountered while accessing file : "
    AUTH_ERROR = "Check Authentication Type (HTTP_Signature/JWT) in cybs.json."
    KEY_ALIAS_NULL_EMPTY = "KeyAlias Empty/None. Assigining merchantID value"
    INVALID_KEY_ALIAS = "KeyAlias Invalid. Assigining merchantID value"
    REQUEST_JSON_ERROR = "Request Json File missing. File Path :: "
    KEY_FILE_EMPTY = "KeyFileName is empty, Assigining merchantID value"
    REFER_LOG = "Please refer Log for details"
    MERCHANTID_REQ = "MerchantID is mandatory"
    NOT_ENTERED = "The Following Parameter is Missing in Cybs.Json::"
    INCORRECT_KEY_PASSWORD = "The Entered key_password is Incorrect"
    AUTHENTICATION_REQ = "AuthenticationType is Mandatory"
    MERCHANT_KEY_ID_REQ = "MerchantKeyId is Mandatory"
    MERCHANT_SECRET_KEY_REQ = " MerchantSecretKey is Mandatory"
    PORTFOLIO_ID_REQ = " Portfolio ID is Mandatory"
    KEY_PASSWORD_EMPTY = "KeyPassword Empty/None. Assigining merchantID value"
    INVALID_KEY_PASSWORD = "KeyPassword Invalid. Assigining merchantID value"
    KEY_DIRECTORY_EMPTY = "KeysDirectory not provided. Using Default Path:"
    ENABLE_CLIENT_CERT_EMPTY = 'Enable Clientcert is Empty/Null.'
    CLIENT_CERT_DIR_EMPTY = 'Client Cert Directory is Empty/Null'
    SSL_CLIENT_CERT_EMPTY = 'SSL Client Cert is Empty/Null'
    PRIVATE_KEY_EMPTY = 'Private Key is Empty/Null'
    SSL_KEY_PASSWORD_EMPTY = 'SSL Key Password is Empty/Null'
    CLIENT_ID_EMPTY = 'Client Id is Empty/Null'
    CLIENT_SECRET_EMPTY = 'Client Secret is Empty/Null'
    ACCESS_TOKEN_EMPTY = 'AccessToken is Empty/Null'
    REFRESH_TOKEN_EMPTY = 'RefreshToken is Empty/Null'
    REQUEST_JSON_EMPTY = "RequestJsonPath not provided"
    INVALID_REQUEST_TYPE_METHOD = "Entered Request Type should be (GET/POST/PUT/PATCH)"
    RUN_ENVIRONMENT_EMPTY = "RunEnvironment Is Mandatory."
    DEFAULT_LOG_FILE_NAME = "Log File Name Empty/None.Using Default Value"
    DEFAULT_ENABLE_LOG = False
    DEFAULT_ENABLE_MASKING = False
    DEFAULT_MAXIMUM_SIZE = 10487560
    DEFAULT_LOG_DATE_FORMAT = "%Y-%m-%d %H:%M:%S"
    DEFAULT_LOG_FORMAT = "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    DEFAULT_LOG_LEVEL = "WARNING"
    DEFAULT_TIMEOUT = 1000
    DEFAULT_LOG_DIRECTORY =os.path.join(os.getcwd(),"Logs")
    DEFAULT_PROXY_PORT = 443
    DEFAULT_KEY_FILE_PATH = os.path.join(os.getcwd(),"resources")
    ENABLE_LOG_DEFAULT_MESSAGE = "Enable log value Empty/None.Using Default Value"
    LOG_MAXIMUM_SIZE_DEFAULT_MESSAGE = "Log Maximum Size Empty/None.Using Default Value"
    LOG_DIRECTORY_DEFAULT_MESSAGE = "Log Directory value Empty/None.Using Default Value"
    LOG_DIRECTORY_INCORRECT_MESSAGE = "Log Directory value Incorrect.Using Default Value"
    INVALID_CYBS_PATH = "The Cybs.Json Path Provided Is Incorrect"
    DEPRECATED_RUN_ENVIRONMENT = "The value provided for this field `RunEnvironment` has been deprecated and will not be used anymore.\n\nPlease refer to the README file [ https://github.com/CyberSource/cybersource-rest-samples-node/blob/master/README.md ] for information about the new values that are accepted."
